# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2019 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

from __future__ import print_function
from __future__ import division
from __future__ import absolute_import
import subprocess
import shlex


def parse_command(command):
    """
    Parses a command string into a list of arguments.
    """
    if isinstance(command, str):
        if command.strip() == "":
            return []
        return shlex.split(command)
    elif isinstance(command, list):
        return command
    else:
        return []

def exec_command(command, env=None):
    """
    Execute command
    """
    result = []
    try:
        args = parse_command(command)
        if not args:
            raise ValueError(f"The provided command is not valid: {command}")
        p = subprocess.Popen(args, stdout=subprocess.PIPE, env=env, text=True)
        while 1:
            output = p.stdout.readline()
            if not output:
                break
            if output.strip() != "":
                result.append(output.strip())
    except Exception as inst:
        print("Call process error:", str(inst))
    return result


def exec_command_check(command):
    """
    Execute command and check output
    """
    try:
        args = parse_command(command)
        if not args:
            raise ValueError(f"The provided command is not valid: {command}")
        p = subprocess.Popen(args, stdout=subprocess.PIPE, env=env, text=True)
        (res_in_json, err) = p.communicate()
        if (p.returncode != 0):
            return False
        return True
    except Exception as inst:
        print("Call process error(" + command + "): " + str(inst))
    return False
